"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SpiralAbyss = void 0;
const tslib_1 = require("tslib");
const request_1 = require("../utils/request");
const getServer_1 = require("../utils/getServer");
const base_1 = require("./base");
const validator_1 = require("../utils/validator");
const mergeOptions_1 = tslib_1.__importDefault(require("../utils/mergeOptions"));
class SpiralAbyss extends base_1.BaseRoute {
    constructor(options) {
        super(options);
    }
    /**
     * @param {string} uid Genshin Impact UID
     */
    async fetch(uid, options) {
        if (this.cache?.has(uid))
            return this.cache.get(uid);
        const optionsToUse = (0, mergeOptions_1.default)(options, this.cookieManager, this.defaultOptions);
        if (!(0, validator_1.spiralAbyssValidator)(uid, optionsToUse)) {
            throw new Error("No UID or Cookie provided");
        }
        const { language, cookie, previous } = optionsToUse;
        const instance = new request_1.request({
            withDS: true,
            withExtraHeaders: true,
            language,
        });
        const res = await instance.get("spiralAbyss", {
            Cookie: cookie,
        }, {
            server: (0, getServer_1.checkServerRegion)(uid),
            role_id: uid,
            schedule_type: previous ? "2" : "1",
        });
        const { data } = res;
        if (this.cache) {
            this.cache.set(uid, data);
        }
        return data;
    }
}
exports.SpiralAbyss = SpiralAbyss;
